Connection
==========

An http connection package with connection pooling.

Since version 0.6 it is safe to use threaded connections.

The Connection package uses httplib, standard python threads and a connection pooling mechanism.

.. note:: Since version 0.6.2 the underlying pooling mechanism is packed in a new GRNET package called *objpool*.

.. automodule:: kamaki.clients.connection
    :members:
    :show-inheritance:
    :undoc-members:
